<?php

namespace Drupal\plotly_js\Commands;

use Drupal\Core\File\FileSystemInterface;
use Drush\Commands\DrushCommands;
use GuzzleHttp\Client;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * A Drush 9 command to download the Plotly.js library.
 */
class PlotlyJsCommands extends DrushCommands {

  /**
   * The HTTP client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $client;

  /**
   * The file system.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * PlotlyJsCommands constructor.
   *
   * @param \GuzzleHttp\Client $client
   *   The HTTP client.
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system.
   */
  public function __construct(Client $client, FileSystemInterface $file_system) {
    parent::__construct();
    $this->client = $client;
    $this->fileSystem = $file_system;
  }

  /**
   * Downloads the Plotly.js library and places it in the libraries' folder.
   *
   * @param \Symfony\Component\Console\Output\OutputInterface $output
   *   The output interface.
   *
   * @command plotly_js:download-plotly
   * @aliases download-plotly, plotly_js-download-plotly
   */
  public function downloadPlotly(OutputInterface $output) {
    try {
      $url = 'https://cdn.plot.ly/plotly-latest.min.js';
      $response = $this->client->get($url);
      $contents = $response->getBody()->getContents();
      $directory = 'libraries/plotly';
      $this->fileSystem->prepareDirectory($directory, FileSystemInterface::CREATE_DIRECTORY);
      $file = $directory . '/plotly-latest.min.js';
      $this->fileSystem->saveData($contents, $file);
      $output->writeln("<info>The Plotly.js library was downloaded to the $directory folder.</info>");
    }
    catch (\Exception $e) {
      $output->writeln("<error>An error occurred while downloading the library: {$e->getMessage()}</error>");
    }
  }

}
